@@ -152,6 +152,7 @@ gkbd_status_render_cairo (cairo_t * cr, int group)
 	cairo_font_options_t *fo;
 	static GHashTable *ln2cnt_map = NULL;
 
+	xkl_debug (160, "Rendering cairo for group %d\n", group);
 	if (globals.ind_cfg.background_color != NULL &&
 	    globals.ind_cfg.background_color[0] != 0) {
 		if (sscanf
@@ -631,6 +632,9 @@ gkbd_status_init (GkbdStatus * gki)
 
 	gki->priv = g_new0 (GkbdStatusPrivate, 1);
 
+	/* This should give NA a hint about the order */
+	gtk_status_icon_set_name (GTK_STATUS_ICON(gki), "keyboard");
+
 	xkl_debug (100, "Initiating the widget startup process for %p\n",
 		   gki);
 
